@@ -1,5 +1,6 @@
 from .dynamicsterm import DynamicsTerm
 from .precession import Precession
 from .damping import Damping
-from .stt import STT
+from .zhangli import ZhangLi
+from .slonczewski import Slonczewski
 from .dynamics import Dynamics
