@@ -26,3 +26,12 @@ class Energy(mm.abstract.Container):
 
     """
     _term_class = EnergyTerm
+
+    def energy(self, m):
+        raise NotImplementedError  # can be implemented as (Heff*m).integrate
+
+    def density(self, m):
+        raise NotImplementedError  # can be implemented as Heff*m
+
+    def effective_field(self, m):
+        pass  # pragma: no cover
